@@ -59,13 +59,13 @@
     #include <X11/extensions/Xcomposite.h>
     #include <X11/extensions/Xdamage.h>
     #include <X11/extensions/Xrender.h>
-
 #elif  NONMAEMO
     #include <hildon/hildon-banner.h>
 #elif  OS2009
     #include <libhildondesktop/libhildondesktop.h>
     #include <hildon/hildon-banner.h>
     #include <hildon/hildon-window-stack.h>
+    #include <hildon/hildon.h>
 #else
     #include <hildon-widgets/hildon-banner.h>
 #endif
@@ -80,45 +80,56 @@
     #include <clutter-gtk/gtk-clutter-util.h>
 #endif
 
-
 #ifdef USE_CONIC
-#include <conic/conic.h>
+  #include <conic/conic.h>
 #endif
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 /*******************************************************************************/
-
 #define _(String) dgettext (GETTEXT_PACKAGE, String)
-#define Max_count_weather_day	10
-#define DATABASEPATH		"/usr/share/omweather/db/"
-#define SOURCESPATH		    "/usr/share/omweather/sources/"
+#define Max_count_weather_day   10
+#define DATABASEPATH        "/usr/share/omweather/db/"
+#define SOURCESPATH         "/usr/share/omweather/sources/"
 #define STYLEPATH           "/usr/share/omweather/"
-#define COPYRIGHT_ICONS		"/usr/share/omweather/copyright_icons/"
-#define COUNTRIESFILE		"countries.list"
-#define REGIONSFILE		    "regions.list"
-#define LOCATIONSFILE		"locations.list"
-#define ICONS_PATH	    	"/usr/share/omweather/icons/"
+#define COPYRIGHT_ICONS     "/usr/share/omweather/copyright_icons/"
+#define COUNTRIESFILE       "countries.list"
+#define REGIONSFILE         "regions.list"
+#define LOCATIONSFILE       "locations.list"
+#define ICONS_PATH          "/usr/share/omweather/icons/"
 #define BUTTON_ICONS		"/usr/share/omweather/button_icons/"
-/*
+#define IMAGES_PATH         "/usr/share/omweather/images/"
+
 #define START_FUNCTION        fprintf(stderr,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);
 #define END_FUNCTION		fprintf(stderr,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);
-*/
-
-extern void write_log(char *string);
-#define START_FUNCTION          FILE *file; file=fopen("/tmp/omw.log","a+"); fprintf(file,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);fflush(file);fclose(file);
+/*
+#define START_FUNCTION          FILE *f; f=fopen("/tmp/omw.log","a+"); fprintf(f,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);fflush(f);fclose(f);
 #define DEBUG_FUNCTION(string)  write_log(string)
 #define END_FUNCTION          FILE *fileend; fileend=fopen("/tmp/omw.log","a+"); fprintf(fileend,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);fflush(fileend);fclose(fileend);
+*/
+#define OMWEATHER_ADD_STATION           1000
+#define OMWEATHER_SEARCH_STATION        1001
+#define OMWEATHER_CLOSE_STATION_WINDOW  1002
+#define PRESET_BIG_FONT "Sans Bold 32"
+#define PRESET_MEDIUM_FONT "Sans Bold 21"
+#define PRESET_DAY_FONT "Sans 16"
+#define PRESET_TEMPERATURE_FONT "Sans 19"
+#define PRESET_WIND_FONT "Sans 13"
+#define PRESET_STATION_FONT "Sans 15"
+/*#define PRESET_BIG_FONT "Bitstream Vera Sans Bold 38"*/
+#define PRESET_BIG_FONT_COLOR_FRONT "#FFFFFF"
+#define PRESET_BIG_FONT_COLOR_BACK "#000000"
+#define PRESET_WIND_FONT_COLOR "#000000"
+#define PRESET_FONT_COLOR_LOW_TEMP "#7D9CAD"
 
-#define OMWEATHER_ADD_STATION		1000
-#define OMWEATHER_SEARCH_STATION	1001
-#define OMWEATHER_CLOSE_STATION_WINDOW	1002
 /*******************************************************************************/
 enum { AUTOUPDATE, CHANGE_DAY_PART, DBUSINITEVENT, UPDATE_AFTER_CONNECTED,
-	CHECK_GPS_POSITION
-};
-enum { ONE_ROW, ONE_COLUMN, TWO_ROWS, TWO_COLUMNS, COMBINATION, APPLICATION_MODE };
+       CHECK_GPS_POSITION};
+enum { UNKNOWN_DIRECTION, TO_NORTH, TO_NORTH_EAST, TO_EAST, TO_SOUTH_EAST, TO_SOUTH, TO_SOUTH_WEST, TO_WEST, TO_NORTH_WEST };
+enum { ONE_ROW, ONE_COLUMN, TWO_ROWS, TWO_COLUMNS, COMBINATION, PRESET_NOW, PRESET_NOW_PLUS_TWO, PRESET_NOW_PLUS_THREE_V,
+       PRESET_NOW_PLUS_THREE_H, PRESET_NOW_PLUS_SEVEN, APPLICATION_MODE };
+enum { FIRST_BUTTON, OTHER_BUTTON };
 enum { RIGHT, LEFT, TOP, BOTTOM, NOTHING };
 enum { METERS, KILOMETERS, MILES, SEA_MILES };
 enum { METERS_S, KILOMETERS_H, MILES_H };
@@ -128,36 +139,42 @@ enum { ICON, STATION_NAME };
 enum { MB, INCH, MM };
 enum { WEATHER_COM, RP5_RU, MAX_WEATHER_SOURCE_NUMBER };
 enum { TINY_ICON_SIZE = 32, SMALL_ICON_SIZE = 48, MEDIUM_ICON_SIZE = 64,
-	BIG_ICON_SIZE = 80, LARGE_ICON_SIZE = 96, GIANT_ICON_SIZE = 128,
-	SUPER_GIANT_ICON_SIZE = 256
-};
+       BIG_ICON_SIZE = 80, LARGE_ICON_SIZE = 96, GIANT_ICON_SIZE = 128,
+       SUPER_GIANT_ICON_SIZE = 256};
 enum { SETTINGS_STATIONS_PAGE, SETTINGS_VISUALS_PAGE, SETTINGS_DISPLAY_PAGE,
-	SETTINGS_UNITS_PAGE, SETTINGS_UPDATE_PAGE,
+       SETTINGS_UNITS_PAGE, SETTINGS_UPDATE_PAGE,
 #if defined(OS2008) || defined(OS2009) || defined(NONMAEMO)
-	SETTINGS_SENSOR_PAGE,
+       SETTINGS_SENSOR_PAGE,
 #endif
-	ALERTS_PAGE, MAX_SETTINGS_PAGE_NUMBER, ABOUT_PAGE
+       ALERTS_PAGE, MAX_SETTINGS_PAGE_NUMBER, ABOUT_PAGE
 };
-enum {SHORT_CLICK, LONG_CLICK};
+enum { SIMPLE_MODE, EXTENDED_MODE };
+enum { SHORT_CLICK, LONG_CLICK };
+enum {COLLAPSED_VIEW_MODE, EXPANDED_VIEW_MODE};
+
 /* station tab */
 enum { STATE_ENABLE_GPS	= 1U,
        STATE_SOURCE	= 2U
 };
 /* visuals tab */
-enum { STATE_ONE_ROW		= 1U,
-       STATE_ONE_COLUMN		= 2U,
-       STATE_TWO_ROWS		= 4U,
-       STATE_TWO_COLUMNS	= 8U,
-       STATE_COMBINATION	= 16U,
-       STATE_THEME_OVERRIDE	= 32U,
-       STATE_TRANSPARENCY	= 64U,
-       STATE_FONT		= 128U,
-       STATE_FONT_COLOR		= 256U,
-       STATE_BACKGROUND_COLOR	= 512U,
-       STATE_ICONSET        = 1024U,
-       STATE_LONG           = 2048U,
-       STATE_SHORT          = 4096U
-
+enum { STATE_ONE_ROW            = 1U,
+       STATE_ONE_COLUMN         = 2U,
+       STATE_TWO_ROWS           = 4U,
+       STATE_TWO_COLUMNS        = 8U,
+       STATE_COMBINATION        = 16U,
+       STATE_THEME_OVERRIDE     = 32U,
+       STATE_TRANSPARENCY       = 64U,
+       STATE_FONT               = 128U,
+       STATE_FONT_COLOR         = 256U,
+       STATE_BACKGROUND_COLOR   = 512U,
+       STATE_ICONSET            = 1024U,
+       STATE_LONG               = 2048U,
+       STATE_SHORT              = 4096U,
+       STATE_PRESET_NOW               = 8192U,
+       STATE_PRESET_NOW_PLUS_TWO      = 16384U,
+       STATE_PRESET_NOW_PLUS_THREE_V  = 32768U,
+       STATE_PRESET_NOW_PLUS_THREE_H  = 65536U,
+       STATE_PRESET_NOW_PLUS_SEVEN    = 131072U
 };
 /* display tab */
 enum { STATE_VISIBLE_ITEMS	= 1U,
@@ -201,37 +218,16 @@ enum { STATE_USE_SENSOR		= 1U,
        STATE_SENSOR_READ_TIME	= 8U
 };
 /*******************************************************************************/
-typedef struct{
-    gint	error;
-    xmlDoc	*doc;
-    xmlNode	*weather_com_root;
-}weather_com_parser;
-/*******************************************************************************/
-typedef struct{
-    GSList	*location;
-    GSList	*current;
-    GSList	*days;
-    gboolean	current_data_is_invalid;
-    gboolean	hours_data_is_invalid;
-    GSList      *hours_weather;
-}WeatherStationData;
-/*******************************************************************************/
-typedef struct weather_data_source{
-    gchar	*name;
-    gchar	*url;
-    gchar	*hour_url;
-    gchar	*encoding;
-    gint 	(*parser)(const gchar *station_id, weather_com_parser *parser,
-			    WeatherStationData *wsd);
-    gint 	(*parser_hour)(const gchar *station_id, weather_com_parser *parser,
-				WeatherStationData *wsd);
-}WeatherSource;
-/*******************************************************************************/
 typedef struct weather_day_button_with_image{
-    GtkWidget	*button;
-    GtkWidget	*label;
-    GtkWidget	*box;
-    GtkWidget   *icon_image; 
+    GtkWidget   *button;
+    GtkWidget   *label;
+    GtkWidget   *shadow_label;
+    GtkWidget   *box;
+    GtkWidget   *icon_image;
+    GtkWidget   *wind;
+    GtkWidget   *wind_text;
+    GtkWidget   *wind_label;
+    GtkWidget   *background;
 }WDB;
 /*******************************************************************************/
 struct event_time{
@@ -262,62 +258,67 @@ typedef	struct{
 }Region_item;
 /*******************************************************************************/
 typedef struct{
-    char	name[50];
-    char	id0[10];
-    char	id1[10];
-    double	latitude;
-    double	longtitude;
+    char    name[50];
+    char    id0[10];
+    char    id1[10];
+    double  latitude;
+    double  longtitude;
 }Station;
 /*******************************************************************************/
 enum{ NAME_COLUMN = 0, ID0_COLUMN, ID1_COLUMN, LATITUDE_COLUMN,
 	LONGTITUDE_COLUMN };
 /*******************************************************************************/
 typedef struct applet_config{
-    gchar	*cache_dir_name;
-    gchar	*icons_set_base;
-    gchar	*icon_set;
-    gchar	*font;
-    gchar	*current_source;
-    gchar	*current_country;
-    gchar	*current_station_name;
-    gchar	*current_station_id;
-    gchar	*current_station_source;
-    gchar 	*iap_http_proxy_host;
-    gchar 	*cache_directory;
-    gint 	iap_http_proxy_port;
-    gint	update_interval;
-    gint	switch_time;
-    gint	icons_size;
-    gint	icons_layout;
-    gint	text_position;
-    gint	current_settings_page;
-    gint	days_to_show;
-    gint	previos_days_to_show;
-    gint	distance_units;
-    gint	wind_units;
-    gint        clicking_type;
-    gint        temperature_units;
-    gint        pressure_units;
+    gchar   *cache_dir_name;
+    gchar   *icons_set_base;
+    gchar   *icon_set;
+    gchar   *font;
+    gchar   *current_source;
+    gchar   *current_country;
+    gchar   *current_station_name;
+    gchar   *current_station_id;
+    gchar   *current_station_source;
+    gchar   *iap_http_proxy_host;
+    gchar   *cache_directory;
+    gint    iap_http_proxy_port;
+    gint    update_interval;
+    gint    switch_time;
+    gint    icons_size;
+    gint    icons_layout;
+    gint    text_position;
+    gint    current_settings_page;
+    gint    days_to_show;
+    gint    previos_days_to_show;
+    gint    distance_units;
+    gint    wind_units;
+    gint    clicking_type;
+    gint    temperature_units;
+    gint    pressure_units;
+    gint    mode;
 #if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
-    gint	display_at;
-    gboolean	use_sensor;
-    guint	sensor_update_time;
-    guint 	alpha_comp;
-    guint	corner_radius;
+    gint        display_at;
+    gboolean    use_sensor;
+    guint       sensor_update_time;
+    guint       alpha_comp;
+    guint       corner_radius;
 #endif
-    guint	data_valid_interval;
-    gboolean	transparency;
-    gboolean	separate;
-    gboolean	swap_hi_low_temperature;
-    gboolean	show_station_name;
-    gboolean	show_arrows;
-    gboolean	downloading_after_connecting;
+    guint       data_valid_interval;
+    gboolean    transparency;
+    gboolean    separate;
+    gboolean    swap_hi_low_temperature;
+    gboolean    show_station_name;
+    gboolean    show_arrows;
+    gboolean    downloading_after_connecting;
     gboolean    gps_station;
-    gboolean	show_wind;
-    gboolean	show_wind_gust;
+    gboolean    show_wind;
+    gboolean    show_wind_gust;
     gboolean    show_weather_for_two_hours;
-    GdkColor	font_color;
-    GdkColor	background_color;
+    GdkColor    font_color;
+    GdkColor    background_color;
+    gboolean    is_application_mode;
+    gboolean	update_gsm;
+    gboolean	update_wlan;
+    gint	view_mode;
 }AppletConfig;
 /*******************************************************************************/
 #ifdef CLUTTER
@@ -339,7 +340,8 @@ typedef struct OMWeatherApplet{
     GtkWidget           *main_view; /* handle to app's view */
     osso_context_t	*osso;
     GHashTable		*hash,
-			*sources_units;
+                    *sources_units;
+    GHashTable      *station_data;
     GtkWidget		*top_widget;
     GtkWidget		*main_window;
     GtkWidget		*popup_window;
@@ -403,7 +405,6 @@ typedef struct OMWeatherApplet{
     gint		ah;
     GSList		*tab_of_window_popup;
     GSList		*handles;
-    WeatherStationData  wsd;
     GSList              *sources;
     GSList              *clutter_objects_in_main_form;
     GSList              *clutter_objects_in_popup_form;
@@ -415,8 +416,8 @@ typedef struct OMWeatherApplet{
     LocationGPSDevice   *gps_device;
     LocationGPSDControl *gps_control;
     Station		gps_station;
-    gdouble		temporary_station_latitude;
-    gdouble		temporary_station_longtitude;
+    double		temporary_station_latitude;
+    double		temporary_station_longtitude;
 #endif
 #ifdef OS2009
     gboolean    portrait_position;
@@ -435,6 +436,18 @@ typedef struct OMWeatherApplet{
 #endif
 }OMWeatherApp;
 /*******************************************************************************/
+typedef struct lists_struct{
+    GtkWidget       *countries;
+    GtkListStore    *countries_list;
+    GtkWidget       *states;
+    GtkListStore    *regions_list;
+    GtkWidget       *stations;
+    GtkListStore    *stations_list;
+    GtkListStore    *sources_list;
+    sqlite3         *database;
+    gboolean        database_invalid;
+}lists_struct_obj;
+/*******************************************************************************/
 extern	OMWeatherApp	*app;
 /*******************************************************************************/
 #ifdef OS2008 
