@@ -28,7 +28,14 @@
 */
 /*******************************************************************************/
 #include "weather-config.h"
+#include "weather-stations.h"
+#include "weather-utils.h"
+#include "weather-event.h"
 #include "weather-alerts.h"
+#include "weather-home.h"
+#if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
+#include "weather-sensor.h"
+#endif
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -128,11 +135,16 @@ void fill_user_stations_list_from_clock(GtkListStore ** list) {
                 gtk_list_store_set(*list, &iter,
                                    NAME_COLUMN, station_name,
                                    ID0_COLUMN, station_code,
+#if defined(ENABLE_GPS)
+                                   2, FALSE,
+#endif
+                                   3, g_strdup("weather.com"),
                                    -1);
                 /* A current station */
                 if (!strncmp(buffer, home_city, tmp - buffer)) {
                     app->config->current_station_id = station_code;
                     app->config->current_station_name = station_name;
+                    app->config->current_station_source = g_strdup("weather.com");
                 }
             }
         }
@@ -147,14 +159,17 @@ void fill_user_stations_list_from_clock(GtkListStore ** list) {
 /*******************************************************************************/
 void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
     GtkTreeIter	iter;
-    gchar	*temp1 = NULL,
-		*temp2 = NULL,
-		*temp3 = NULL,
-		*station_name = NULL,
-		*station_code = NULL,
-		*station_source = NULL;
+    gchar   *temp1 = NULL,
+            *temp2 = NULL,
+            *temp3 = NULL,
 #ifdef ENABLE_GPS
-    gboolean	is_gps = FALSE;
+            *temp4 = NULL,
+#endif
+            *station_name = NULL,
+            *station_code = NULL,
+            *station_source = NULL;
+#ifdef ENABLE_GPS
+    gboolean    is_gps = FALSE;
 #endif
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -166,8 +181,9 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
             /* station name */
             temp2 = strtok(temp1, "@"); /* Delimiter - @ */
             if (temp2)          /* Check random error */
-                if (strlen(temp2) > 0)
+                if (strlen(temp2) > 0){
                     station_code = g_strdup(temp2);
+                }
             /* station code */
             temp2 = strtok(NULL, "@");  /* Delimiter - @ */
             if (temp2)
@@ -176,11 +192,18 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
             temp3 = strtok(NULL, "@");
             if (temp3)
                 station_source = g_strdup(temp3);
+            /* weather.com by default */
+            if (!station_source || (!strcmp(station_source,"(null)"))){
+                if (station_source)
+                   g_free(station_source);
+                station_source = g_strdup("weather.com");
+            }
+
+	    fprintf(stderr,"%s : %s : %s \n", station_code, station_name, station_source );
 #ifdef ENABLE_GPS
-            if (app->gps_station.id0 && app->gps_station.name &&
-                station_code && station_name &&
-                !strcmp(app->gps_station.id0, station_code) &&
-                !strcmp(app->gps_station.name, station_name))
+            /* gps or manual station */
+            temp4 = strtok(NULL, "@");
+            if (temp4 && !strcmp("G",temp4))
                 is_gps = TRUE;
             else
                 is_gps = FALSE;
@@ -201,15 +224,30 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
 #endif
                                    -1);
             }
-            if (!strcmp(station_name, app->config->current_station_name)
+            if (app->config->current_station_name && app->config->current_station_id
+                && (!strcmp(station_name, app->config->current_station_name)
                 && !strcmp(station_code, app->config->current_station_id)
-                && !app->config->current_station_source) {
+                && !app->config->current_station_source)) {
                 app->config->current_station_source = g_strdup(station_source);
             }
+            if (!app->config->current_station_id) {
+                app->config->current_station_id = g_strdup(station_code);
+                app->config->current_station_name = g_strdup(station_name);
+                app->config->current_station_source = g_strdup("weather.com");
+            }
 
-            station_name && (g_free(station_name), station_name = NULL);
-            station_code && (g_free(station_code), station_code = NULL);
-            station_source && (g_free(station_source), station_source = NULL);
+            if(station_name){
+                g_free(station_name);
+                station_name = NULL;
+            }
+            if(station_code){
+                g_free(station_code);
+                station_code = NULL;
+            }
+            if(station_source){
+                g_free(station_source);
+                station_source = NULL;
+            }
         }
         g_free(temp1);
         source_list = g_slist_next(source_list);
@@ -217,13 +255,15 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
 }
 /*******************************************************************************/
 GSList *create_stations_string_list(void) {
-    GSList	*stlist = NULL;
-    GtkTreeIter	iter;
+    GSList      *stlist = NULL;
+    GtkTreeIter iter;
     gboolean	valid;
-    gchar	*station_name = NULL,
-		*station_code = NULL,
-		*station_source = NULL,
-		*str = NULL;
+    gboolean    is_gps;
+    gchar       *station_name = NULL,
+                *station_code = NULL,
+                *station_source = NULL,
+                *str = NULL;
+    gchar       type_of_station = 'M';
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -235,9 +275,31 @@ GSList *create_stations_string_list(void) {
                            &iter,
                            NAME_COLUMN, &station_name,
                            ID0_COLUMN, &station_code,
+                           2, &is_gps,
                            3, &station_source, -1);
-        str = g_strdup_printf("%s@%s@%s", station_code, station_name,
-                              station_source);
+        if (is_gps)
+            type_of_station = 'G';
+        else
+            type_of_station = 'M';
+
+        if (!station_source || (!strcmp(station_source,"(null)"))){
+                if (station_source)
+                   g_free(station_source);
+                station_source = g_strdup("weather.com");
+        }
+        if (!station_name || (!strcmp(station_name,"(null)"))){
+                if (station_name)
+                   g_free(station_name);
+                station_name = g_strdup(" ");
+        }
+        if (!station_code || (!strcmp(station_code,"(null)"))){
+                if (station_code)
+                   g_free(station_code);
+                station_code = g_strdup(" ");
+        }
+
+        str = g_strdup_printf("%s@%s@%s@%c", station_code, station_name,
+                              station_source, type_of_station);
         stlist = g_slist_append(stlist, str);
         g_free(station_name);
         g_free(station_code);
@@ -289,6 +351,7 @@ gint read_config(AppletConfig * config) {
     GdkColor DEFAULT_FONT_COLOR = { 0, 0xFF00, 0xFF00, 0x0000 };
     GdkColor DEFAULT_BACKGROUND_FONT_COLOR = { 0, 0x0000, 0x0000, 0x0000 };
     gchar tmp_buff[1024], *home_dir, *tmp = NULL;
+    gboolean first_start = FALSE;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -298,6 +361,18 @@ gint read_config(AppletConfig * config) {
         fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
         return 1;
     }
+    /* Check first start then  */
+    tmp = NULL;
+    tmp = gconf_client_get_string(gconf_client,
+                                  GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);
+    if (!tmp) {
+        first_start = TRUE;
+    } else {
+        g_free(tmp);
+        tmp = NULL;
+        first_start = FALSE;
+    }
+
     /* Get Weather Cache Directory.  Default is "~/apps/omweather". */
     tmp = gconf_client_get_string(gconf_client,
                                   GCONF_KEY_WEATHER_DIR_NAME, NULL);
@@ -326,6 +401,16 @@ gint read_config(AppletConfig * config) {
         (gnome_vfs_expand_initial_tilde(tmp_buff)))
         fprintf(stderr, _("Could not create weather cache directory.\n"));
 
+    /* Get MODE  Default SIMPLE */
+    config->mode = SIMPLE_MODE;
+    config->mode = gconf_client_get_int(gconf_client,
+                                                GCONF_KEY_MODE,
+                                                NULL);
+    if (config->mode < SIMPLE_MODE
+        || config->mode > EXTENDED_MODE)
+        config->mode = SIMPLE_MODE;
+
+
     /* Get Weather source name. */
     config->current_source = gconf_client_get_string(gconf_client,
                                                       GCONF_KEY_WEATHER_CURRENT_SOURCE_NAME,
@@ -389,6 +474,7 @@ gint read_config(AppletConfig * config) {
         g_slist_foreach(stlist, (GFunc)g_free, NULL);
         g_slist_free(stlist);
     }
+
     /* Get user alerts list */
     stlist = gconf_client_get_list(gconf_client,
                                    GCONF_KEY_WEATHER_ALERTS_LIST,
@@ -408,7 +494,6 @@ gint read_config(AppletConfig * config) {
     } else
         close(fd);
 
-
     /* Get Weather Icon Size  */
     config->icons_size = gconf_client_get_int(gconf_client,
                                               GCONF_KEY_WEATHER_ICONS_SIZE,
@@ -442,6 +527,10 @@ gint read_config(AppletConfig * config) {
         add_gps_event(1);
     } else
         config->gps_station = FALSE;
+//#ifdef OS2009
+        config->gps_station = TRUE;
+        add_gps_event(1);
+//#endif
 #endif
 
     /* Get Weather font color. */
@@ -491,6 +580,10 @@ gint read_config(AppletConfig * config) {
         gconf_value_free(value);
     } else
         config->show_weather_for_two_hours = TRUE;
+    /* Hack This parameter is default for SIMPLE mode */
+    if (config->mode == SIMPLE_MODE)
+        config->show_weather_for_two_hours = TRUE;
+
     /* Get Split Button State. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SEPARATE_DATA, NULL);
     if (value) {
@@ -606,13 +699,19 @@ gint read_config(AppletConfig * config) {
         gerror = NULL;
     }
 
-    /* Get Layout  Default Horizontal */
+    /* Get Layout Default Preset ONE */
     config->icons_layout = gconf_client_get_int(gconf_client,
                                                 GCONF_KEY_ICONS_LAYOUT,
                                                 NULL);
     if (config->icons_layout < ONE_ROW
-        || config->icons_layout > COMBINATION)
-        config->icons_layout = ONE_ROW;
+        || config->icons_layout > PRESET_NOW_PLUS_SEVEN || first_start)
+        config->icons_layout = PRESET_NOW;
+
+    /*!!!!!!!!!!!!!!!! Tempory hack !!!!!!!!!!!!!!
+    config->icons_layout = PRESET_NOW;
+
+    */
+
 
     /* Get Text Position  Default Right */
     config->text_position = RIGHT;
@@ -723,32 +822,50 @@ gint read_config(AppletConfig * config) {
         config->data_valid_interval *= 3600;
 
     /* If this first start then fill default station from clock config */
-    tmp = NULL;
-    tmp = gconf_client_get_string(gconf_client,
-                                  GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);
-    if (!tmp) {
+    if (first_start) {
         if (!app->config->current_station_id) {
             fill_user_stations_list_from_clock(&app->user_stations_list);
             if (app->iap_connected)
                 update_weather(TRUE);
         }
-    } else {
-        g_free(tmp);
-        tmp = NULL;
     }
+
+    /*Get GSM and WLAN Default only GSM*/
+    value = gconf_client_get(gconf_client, GCONF_KEY_UPDATE_GSM, NULL);
+    if (value) {
+        config->update_gsm = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    } else
+        config->update_gsm = TRUE;
+
+    value = gconf_client_get(gconf_client, GCONF_KEY_UPDATE_WLAN, NULL);
+    if (value) {
+        config->update_wlan = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    } else
+        config->update_wlan = FALSE;
+
+    /*Get VIEW_MODE Default COLLAPSED*/
+    config->view_mode = COLLAPSED_VIEW_MODE;
+    config->view_mode = gconf_client_get_int(gconf_client,
+                                       GCONF_KEY_VIEW_MODE,
+                                                     NULL);
+    if (config->view_mode < COLLAPSED_VIEW_MODE
+                || config->mode > EXPANDED_VIEW_MODE)
+                        config->view_mode = COLLAPSED_VIEW_MODE;
+    check_current_station_id();
     gconf_client_clear_cache(gconf_client);
     g_object_unref(gconf_client);
-
     return 0;
 }
 
 /*******************************************************************************/
 void config_update_proxy(void) {
     GConfClient *gconf_client = gconf_client_get_default();
+    gchar *proxy_mode;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    gchar *proxy_mode;
     proxy_mode = gconf_client_get_string(gconf_client,
                                     GCONF_KEY_PROXY_MODE, NULL);
 
@@ -771,7 +888,6 @@ void config_update_proxy(void) {
     }
     g_object_unref(gconf_client);
     g_free(proxy_mode);
-    
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -832,13 +948,13 @@ void config_save(AppletConfig * config) {
                                 NULL);
     /* Save Weather Data Source  */
     if(config->current_station_source)
-	gconf_client_set_string(gconf_client,
-                        	GCONF_KEY_CURRENT_STATION_SOURCE,
-                    		config->current_station_source, NULL);
+        gconf_client_set_string(gconf_client,
+                            GCONF_KEY_CURRENT_STATION_SOURCE,
+                            config->current_station_source, NULL);
     else
-	gconf_client_set_string(gconf_client,
-                        	GCONF_KEY_CURRENT_STATION_SOURCE, "",
-                    		NULL);
+        gconf_client_set_string(gconf_client,
+                            GCONF_KEY_CURRENT_STATION_SOURCE, "",
+                            NULL);
     /* Save icon set name */
     if (config->icon_set)
         gconf_client_set_string(gconf_client,
@@ -982,7 +1098,11 @@ void config_save(AppletConfig * config) {
     gconf_client_set_int(gconf_client,
                          GCONF_KEY_ICONS_LAYOUT, config->icons_layout,
                          NULL);
-    /* Save Layout type. */
+    /* Save Mode. */
+    gconf_client_set_int(gconf_client,
+                         GCONF_KEY_MODE, config->mode,
+                         NULL);
+    /* Save position of text. */
     gconf_client_set_int(gconf_client,
                          GCONF_KEY_TEXT_POSITION, config->text_position,
                          NULL);
@@ -1015,7 +1135,105 @@ void config_save(AppletConfig * config) {
                                     app->gps_station.id0, NULL);
     }
 #endif
+    /*Save GSM update setting*/
+    gconf_client_set_bool(gconf_client,
+                          GCONF_KEY_UPDATE_GSM,
+                          config->update_gsm, NULL);
+    /*Save WLAN update setting*/
+    gconf_client_set_bool(gconf_client,
+                          GCONF_KEY_UPDATE_WLAN,
+                          config->update_wlan, NULL);
+    /*Save View mode*/
+    gconf_client_set_int(gconf_client,
+                             GCONF_KEY_VIEW_MODE, config->view_mode,
+                                                      NULL);
     g_object_unref(gconf_client);
 }
+/***********************************************************************************/
+void check_current_station_id(void) {
+    GtkListStore    *all_information_list = NULL;
+    GtkTreeIter     iter,
+                    iter2;
+    gboolean        valid,
+                    valid_all_information,
+                    equals = FALSE;
+    gchar           *station_name = NULL,
+                    *station_code = NULL,
+                    *station_source = NULL,
+                    *station_country = NULL,
+                    *station_region = NULL,
+                    *is_gps = NULL;
 
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list), 
+                                                                                    &iter);
+    while(valid){
+       gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list), &iter,
+                                        0, &station_name,
+                                        1, &station_code,
+                                        2, &is_gps,
+                                        3, &station_source, -1);
+        if(!strcmp(station_code, app->config->current_station_id)){
+            valid = FALSE;
+            equals = TRUE;
+        }
+        else{
+            valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list), &iter);
+            equals = FALSE;
+        }
+    }
+
+    if(!equals){
+        valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list), &iter);
+        if(valid){
+            gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list), &iter,
+                                                0, &station_name,
+                                                1, &station_code,
+                                                2, &is_gps,
+                                                3, &station_source, -1);
+            app->config->current_station_id = station_code;
+            app->config->current_station_name = station_name;
+            app->config->current_station_source = station_source;
+            all_information_list = get_all_information_about_station(station_source,
+                                                                              station_code);
+            valid_all_information = gtk_tree_model_get_iter_first(GTK_TREE_MODEL
+                                                            (all_information_list), &iter2);
+            if(valid_all_information){
+                gtk_tree_model_get(GTK_TREE_MODEL(all_information_list), &iter2,
+                                                    0, &station_country,
+                                                    1, &station_region, -1);
+                app->config->current_country = station_country;
+            }
+        }
+    }
+        
+
+  /*  while (valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list), &iter,
+                                          0, &station_name,
+                                          1, &station_code,
+                                          2, &is_gps,
+                                          3, &station_source, -1);
+        if(strcmp(station_code, app->config->current_station_id)){
+            app->config->current_station_id = station_code;
+            app->config->current_station_name = station_name;
+            app->config->current_station_source = station_source;
+
+            all_information_list = get_all_information_about_station(station_source,
+                                                                         station_code);
+            valid_all_information = gtk_tree_model_get_iter_first(GTK_TREE_MODEL
+                                                          (all_information_list), &iter2);
+            if(valid_all_information){
+                gtk_tree_model_get(GTK_TREE_MODEL(all_information_list), &iter2,
+                                                  0, &station_country,
+                                                  1, &station_region,
+         //                                         2, &station_country_id,
+           //                                       3, &station_region_id,
+                                                  -1);
+                app->config->current_country = station_country;
+            }
+           fprintf(stderr, "\ncurrent_station_id %s\n", app->config->current_station_id); 
+        }
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(app->user_stations_list), &iter);
+    }*/
+}
 /*******************************************************************************/
