@@ -25,18 +25,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
 */
-/*******************************************************************************/
-
-/*******************************************************************************/
-#ifndef _weather_dbus_h
-#define _weather_dbus 1
-
 /*******************************************************************************/
 #include "weather-common.h"
-#define GCONF_KEY_CURRENT_CONNECTIVITY	"/system/osso/connectivity/IAP/current"
 #ifdef USE_CONIC
     #include <conic/conic.h>
     #define USER_DATA_MAGIC 0xaadcaadc
+    #include "weather-download.h"
 #endif
 
 #include "weather-dbus.h"
@@ -44,11 +38,12 @@
 #if defined OS2009 || defined OS2008
     #include <mce/dbus-names.h>
     #include <mce/mode-names.h>
+    #include "weather-portrait.h"
 #endif
-
+/*******************************************************************************/
+#define GCONF_KEY_CURRENT_CONNECTIVITY	"/system/osso/connectivity/IAP/current"
 #define MCE_MATCH_RULE "type='signal',interface='" MCE_SIGNAL_IF \
                         "',member='" MCE_DEVICE_ORIENTATION_SIG "'"
-
 /*******************************************************************************/
 void
 weather_initialize_dbus(void) {
@@ -102,7 +97,7 @@ weather_initialize_dbus(void) {
         /* Add D-BUS signal handler for 'status_changed' */
         app->dbus_conn = dbus_bus_get(DBUS_BUS_SYSTEM, NULL);
 
-#if !defined OS2008 && !defined OS2009
+#if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
         filter_string =
             g_strdup_printf("interface=%s", ICD_DBUS_INTERFACE);
         /* add match */
@@ -142,6 +137,10 @@ weather_initialize_dbus(void) {
 #endif
         app->dbus_is_initialize = TRUE;
     }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
 }
 /*******************************************************************************/
 void
@@ -152,7 +151,7 @@ weather_deinitialize_dbus(void) {
 #endif
 
     if (app->dbus_conn){
-#if !defined OS2008 && !defined OS2009
+#if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
          dbus_bus_remove_match(app->dbus_conn, ICD_DBUS_INTERFACE, NULL);
          dbus_connection_remove_filter(app->dbus_conn,
              get_connection_status_signal_cb);
@@ -165,5 +164,4 @@ weather_deinitialize_dbus(void) {
 #endif
 
 }
-#endif
 /*******************************************************************************/
