@@ -27,6 +27,11 @@
 */
 /*******************************************************************************/
 #include "weather-download.h"
+#include "weather-event.h"
+#include "weather-config.h"
+#include "weather-home.h"
+#include "weather-sources.h"
+#include "weather-popup.h"
 /*******************************************************************************/
 #ifdef USE_CONIC
 #include <conic/conic.h>
@@ -55,7 +60,7 @@ GtkWidget *create_window_update(void) {
                                         NULL, _("Update weather"));
 }
 /*******************************************************************************/
-#if !defined OS2008 && !defined OS2009
+#if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
 static DBusHandlerResult
 get_connection_status_signal_cb(DBusConnection * connection,
                                 DBusMessage * message, void *user_data) {
@@ -108,41 +113,53 @@ get_connection_status_signal_cb(DBusConnection * connection,
 #ifdef USE_CONIC
 #define OSSO_CON_IC_CONNECTING             0x05
 void
-connection_cb(ConIcConnection * connection,
-              ConIcConnectionEvent * event, gpointer user_data) {
-    const gchar *iap_id, *bearer;
-    ConIcConnectionStatus status;
-    ConIcConnectionError error;
+connection_cb(ConIcConnection *connection, ConIcConnectionEvent *event,
+                                                            gpointer user_data){
+    gchar                   *iap_id,
+                            *bearer;
+    ConIcConnectionStatus   status;
+    ConIcConnectionError    error;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     status = con_ic_connection_event_get_status(event);
     error = con_ic_connection_event_get_error(event);
-    iap_id = con_ic_event_get_iap_id(CON_IC_EVENT(event));
-    bearer = con_ic_event_get_bearer_type(CON_IC_EVENT(event));
+    iap_id = (gchar*)con_ic_event_get_iap_id(CON_IC_EVENT(event));
+    bearer = (gchar*)con_ic_event_get_bearer_type(CON_IC_EVENT(event));
 
-    switch (status) {
-    case CON_IC_STATUS_CONNECTED:
-#ifdef DEBUGFUNCTIONCALL
-        second_attempt = TRUE;
-        update_weather(FALSE);
+    switch(status){
+#if defined OS2009
+        case CON_IC_STATUS_NETWORK_UP: /* TODO. Process this status */
+        break;
 #endif
-        app->iap_connecting = FALSE;
-        app->iap_connected = TRUE;
-        app->iap_connecting_timer = 0;
-        if (app->config->downloading_after_connecting)
-            add_current_time_event();
-        break;
+        case CON_IC_STATUS_CONNECTED:
+#ifdef DEBUGFUNCTIONCALL
+            second_attempt = TRUE;
+            update_weather(FALSE);
+#endif
+            app->iap_connecting = FALSE;
+            if ((bearer && !strncmp(bearer,"WLAN", 4) && app->config->update_wlan) ||
+                (bearer && !strncmp(bearer,"DUN_GSM", 7) && app->config->update_gsm))
+                app->iap_connected = TRUE;
+            else
+                app->iap_connected = FALSE;
+            app->iap_connecting_timer = 0;
+            if((app->config->downloading_after_connecting) &&
+              (bearer && !strncmp(bearer,"WLAN", 4) && app->config->update_wlan) ||
+              (bearer && !strncmp(bearer,"DUN_GSM", 7) && app->config->update_gsm)){
+                add_current_time_event();
+            }
 
-    case CON_IC_STATUS_DISCONNECTED:
-        app->iap_connected = FALSE;
-        app->iap_connecting = FALSE;
-        app->iap_connecting_timer = 0;
         break;
-    case CON_IC_STATUS_DISCONNECTING:
-        app->iap_connected = FALSE;
-        app->iap_connecting = FALSE;
-        app->iap_connecting_timer = 0;
+        case CON_IC_STATUS_DISCONNECTED:
+            app->iap_connected = FALSE;
+            app->iap_connecting = FALSE;
+            app->iap_connecting_timer = 0;
+        break;
+        case CON_IC_STATUS_DISCONNECTING:
+            app->iap_connected = FALSE;
+            app->iap_connecting = FALSE;
+            app->iap_connecting_timer = 0;
         break;
 /*        default:
     	    app->iap_connected = FALSE;
@@ -201,11 +218,9 @@ CURL *weather_curl_init(CURL * my_curl_handle) {
        curl_easy_setopt(my_curl_handle, CURLOPT_TIMEOUT, 30);
     curl_easy_setopt(my_curl_handle, CURLOPT_CONNECTTIMEOUT, 10);
     /* For disabled cache */
-    if (!headers){
-      headers = curl_slist_append(headers, "Cache-Control: no-cache");
-      headers = curl_slist_append(headers, "Pragma: no-cache");
-      curl_easy_setopt(my_curl_handle, CURLOPT_HTTPHEADER, headers);
-    }
+    headers = curl_slist_append(headers, "Cache-Control: no-cache");
+    headers = curl_slist_append(headers, "Pragma: no-cache");
+    curl_easy_setopt(my_curl_handle, CURLOPT_HTTPHEADER, headers);
 
     config_update_proxy();
     /* Set Proxy option */
@@ -223,8 +238,7 @@ CURL *weather_curl_init(CURL * my_curl_handle) {
 }
 /*******************************************************************************/
 void
-free_curl(void)
-{
+free_curl(void){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -237,16 +251,17 @@ free_curl(void)
     app->flag_updating = 0;
 }
 /*******************************************************************************/
-static int data_read(void *buffer, size_t size, size_t nmemb, void *stream) {
+static int 
+data_read(void *buffer, size_t size, size_t nmemb, void *stream){
     int result;
     struct HtmlFile *out = (struct HtmlFile *)stream;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    if (out && !out->stream) {
+    if(out && !out->stream){
         /* open file for writing */
         out->stream = fopen(out->filename, "wb");
-        if (!out->stream)
+        if(!out->stream)
             return -1;          /* failure, can't open file to write */
     }
 #ifndef RELEASE
@@ -256,8 +271,9 @@ static int data_read(void *buffer, size_t size, size_t nmemb, void *stream) {
     return result;
 }
 /*******************************************************************************/
-gboolean download_html(gpointer data) {
-    CURLMsg *msg;
+gboolean
+download_html(gpointer data){
+    CURLMsg *msg = NULL;
     CURLMcode mret;
     fd_set rs, ws, es;
     int max;
@@ -265,23 +281,24 @@ gboolean download_html(gpointer data) {
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    if (app->popup_window && app->show_update_window) {
-        destroy_popup_window();
+    if(app->popup_window && app->show_update_window){
+        if(app->config->mode == SIMPLE_MODE)
+            destroy_popup_window(GINT_TO_POINTER(1));
+        else
+            destroy_popup_window(NULL);
     }
     /* If not connected and it autoupdate do go away */
-    if (!app->show_update_window && !app->iap_connected) {
+    if(!app->show_update_window && !app->iap_connected){
         app->flag_updating = 0;
         return FALSE;
     }
-    if (app->iap_connected)
+    if(app->iap_connected)
         second_attempt = TRUE;
-
 /* Connection wake up */
-    if (app->show_update_window && (!second_attempt)
-        && (!app->iap_connecting)) {
+    if(app->show_update_window && (!second_attempt) && (!app->iap_connecting)){
         app->iap_connecting = TRUE;
 #ifdef USE_CONIC
-        if (app->connection)
+        if(app->connection)
             con_ic_connection_connect(app->connection,
                                       CON_IC_CONNECT_FLAG_NONE);
         else{
@@ -290,8 +307,8 @@ gboolean download_html(gpointer data) {
         }
 #else
     #ifndef NONMAEMO
-        if (osso_iap_connect
-            (OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK) {
+        if(osso_iap_connect
+            (OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK){
             fprintf(stderr,
                     "after 1 osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK)\n");
         }
@@ -302,11 +319,11 @@ gboolean download_html(gpointer data) {
         second_attempt = TRUE;
         return TRUE;
     }
-    if (app->iap_connecting) {
+    if(app->iap_connecting){
         /* Check timeout */
-        if (app->iap_connecting_timer > 150) {
-            if (app->show_update_window) {
-                if (update_window) {
+        if(app->iap_connecting_timer > 150){
+            if(app->show_update_window){
+                if(update_window){
                     gtk_widget_destroy(update_window);
                     update_window = NULL;
                 }
@@ -319,30 +336,28 @@ gboolean download_html(gpointer data) {
             app->iap_connecting = FALSE;
             app->flag_updating = 0;
             return FALSE;
-        } else {
+        }
+        else{
             app->iap_connecting_timer++;
             return TRUE;
         }
     }
-
     second_attempt = FALSE;
     /* The second stage */
     /* call curl_multi_perform for read weather data from Inet */
-    if (curl_multi && CURLM_CALL_MULTI_PERFORM ==
-        curl_multi_perform(curl_multi, &num_transfers)){
+    if(curl_multi && CURLM_CALL_MULTI_PERFORM ==
+            curl_multi_perform(curl_multi, &num_transfers))
         return TRUE;            /* return to UI */
-        }
     /* The first stage */
-    if (!curl_handle && !curl_handle_hour) {
+    if(!curl_handle && !curl_handle_hour){
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>>>>>>>First stage\n");
 #endif
-//        DEBUG_FUNCTION("\n>>>>>>>>>>>First stage\n");
-        if (app->show_update_window)
+        if(app->show_update_window)
             update_window = create_window_update();     /* Window with update information */
         /* get first station */
-        if (!get_station_url
-            (&url, &html_file, &hour_url, &html_file_hour, TRUE)) {
+        if(!get_station_url
+                (&url, &html_file, &hour_url, &html_file_hour, TRUE)){
             app->flag_updating = 0;
             return FALSE;       /* The strange error */
         }
@@ -354,7 +369,7 @@ gboolean download_html(gpointer data) {
         curl_handle = weather_curl_init(curl_handle);
         curl_easy_setopt(curl_handle, CURLOPT_URL, url);
         /* Init curl_mult */
-        if (!curl_multi)
+        if(!curl_multi)
             curl_multi = curl_multi_init();
 
         max = 0;
@@ -362,18 +377,15 @@ gboolean download_html(gpointer data) {
         FD_ZERO(&ws);
         FD_ZERO(&es);
         mret = curl_multi_fdset(curl_multi, &rs, &ws, &es, &max);
-        if (mret != CURLM_OK) {
+        if(mret != CURLM_OK)
             fprintf(stderr, "Error CURL\n");
-        }
-
         /* set options for the curl easy handle */
         curl_easy_setopt(curl_handle, CURLOPT_WRITEDATA, &html_file);
         curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, data_read);
         /* for debug */
         /*    curl_easy_setopt(curl_handle, CURLOPT_URL, "http://127.0.0.1"); */
         /* add the easy handle to a multi session */
-
-        if (app->config->show_weather_for_two_hours) {
+        if(app->config->show_weather_for_two_hours){
             curl_handle_hour = weather_curl_init(curl_handle_hour);
             curl_easy_setopt(curl_handle_hour, CURLOPT_URL, hour_url);
             curl_easy_setopt(curl_handle_hour, CURLOPT_WRITEDATA,
@@ -383,90 +395,82 @@ gboolean download_html(gpointer data) {
         }
 
         curl_multi_add_handle(curl_multi, curl_handle);
-        if (app->config->show_weather_for_two_hours)
+        if(app->config->show_weather_for_two_hours)
             curl_multi_add_handle(curl_multi, curl_handle_hour);
         return TRUE;            /* return to UI */
-    } else {
+    }
+    else{
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>>>>>>>Third stage\n");
 #endif
-//        DEBUG_FUNCTION("\n>>>>>>>>>>>Third stage\n");
         /* The third stage */
         num_msgs = 0;
-        while (curl_multi
+        while(curl_multi
                && (msg = curl_multi_info_read(curl_multi, &num_msgs))) {
-            if (msg->msg == CURLMSG_DONE) {
-                if (msg->easy_handle == curl_handle){
+            if(msg->msg == CURLMSG_DONE){
+                if(msg->easy_handle == curl_handle){
                     /* Clean */
                     mret = curl_multi_remove_handle(curl_multi, curl_handle);       /* Delete curl_handle from curl_multi */
-                    if (mret != CURLM_OK)
+                    if(mret != CURLM_OK)
                        fprintf(stderr, " Error remove handle %p\n",
-                            curl_handle);
+                                curl_handle);
                     curl_easy_cleanup(curl_handle);
                     curl_handle = NULL;
-                    if (url) {
+                    if(url){
                        g_free(url);
                        url = NULL;
                     }
-                    if (html_file.stream) {
+                    if(html_file.stream){
                         fclose(html_file.stream);
                         html_file.stream = NULL;
                     }
-
-                    if (html_file.filename) {
+                    if(html_file.filename){
                         g_free(html_file.filename);
                         html_file.filename = NULL;
                     }
                 }
-                if (curl_handle_hour && msg->easy_handle == curl_handle_hour && app->config->show_weather_for_two_hours){
-
+                if(curl_handle_hour && msg->easy_handle == curl_handle_hour && app->config->show_weather_for_two_hours){
                     mret = curl_multi_remove_handle(curl_multi, curl_handle_hour);  /* Delete curl_handle from curl_multi */
-                    if (mret != CURLM_OK)
+                    if(mret != CURLM_OK)
                         fprintf(stderr, " Error remove handle %p\n",curl_handle);
                     curl_easy_cleanup(curl_handle_hour);
                     curl_handle_hour = NULL;
-                    if (hour_url) {
+                    if(hour_url){
                         g_free(hour_url);
                         hour_url = NULL;
                     }
-                    if (html_file_hour.stream) {
+                    if(html_file_hour.stream){
                             fclose(html_file_hour.stream);
                             html_file_hour.stream = NULL;
                     }
-                    if (html_file_hour.filename) {
+                    if(html_file_hour.filename){
                             g_free(html_file_hour.filename);
                             html_file_hour.filename = NULL;
                     }
                 }
-                if (msg->data.result != CURLE_OK) {     /* Not success of the download */
-                    if (app->show_update_window)
+                if(msg->data.result != CURLE_OK){     /* Not success of the download */
+                    if(app->show_update_window)
                         hildon_banner_show_information
-                            (app->main_window, NULL,
-                             _("Did not download weather"));
-                } else {
-
-                    if (curl_handle_hour || curl_handle)
+                            (app->main_window, NULL, _("Did not download weather"));
+                }
+                else{
+                    if(curl_handle_hour || curl_handle)
                         return TRUE; /* Continue downloading */
                     /* get next station url */
-                    if (!get_station_url(&url, &html_file, &hour_url, &html_file_hour, FALSE)) {        /* Success - all is downloaded */
-                        if (app->show_update_window)
-                            hildon_banner_show_information
-                                (app->main_window, NULL,
-                                 _("Weather updated"));
+                    if(!get_station_url(&url, &html_file, &hour_url, &html_file_hour, FALSE)){        /* Success - all is downloaded */
+                        if(app->show_update_window)
+                            hildon_banner_show_information(app->main_window, NULL,
+                                                            _("Weather updated"));
                         redraw_home_window(FALSE);
 #ifndef RELEASE
-                        fprintf(stderr,
-                                "\n>>>>>>>>>>>>>>End of update cycle\n");
-
+                        fprintf(stderr, "\n>>>>>>>>>>>>>>End of update cycle\n");
 #endif
-//                        DEBUG_FUNCTION("End of update cycle");
-                    } else {
+                    }
+                    else{
 #ifndef RELEASE
-                        fprintf(stderr,
-                                "\n>>>>>Url - %s, File - %s\n",
+                        fprintf(stderr, "\n>>>>>Url - %s, File - %s\n",
                                 url, html_file.filename);
 #endif
-//                        DEBUG_FUNCTION(html_file.filename);
                         /* set options for the curl easy handle */
                         curl_handle = weather_curl_init(curl_handle);
                         curl_easy_setopt(curl_handle, CURLOPT_URL, url);
@@ -474,7 +478,7 @@ gboolean download_html(gpointer data) {
                                          CURLOPT_WRITEDATA, &html_file);
                         curl_easy_setopt(curl_handle,
                                          CURLOPT_WRITEFUNCTION, data_read);
-                        if (app->config->show_weather_for_two_hours) {
+                        if(app->config->show_weather_for_two_hours) {
                             curl_handle_hour =
                                 weather_curl_init(curl_handle_hour);
                             curl_easy_setopt(curl_handle_hour,
@@ -488,26 +492,25 @@ gboolean download_html(gpointer data) {
                         }
                         /* add the easy handle to a multi session */
                         curl_multi_add_handle(curl_multi, curl_handle);
-                        if (app->config->show_weather_for_two_hours)
+                        if(app->config->show_weather_for_two_hours)
                             curl_multi_add_handle(curl_multi,
                                                   curl_handle_hour);
                         return TRUE;    /* Download next station */
                     }
                 }
                 /* Clean all */
-                if (update_window) {
+                if(update_window){
                     gtk_widget_destroy(update_window);
                     update_window = NULL;
                 }
                 curl_multi_cleanup(curl_multi);
                 free_curl();
-//                DEBUG_FUNCTION("This is the end");
                 return FALSE;   /* This is the end */
             }
         }
-        if (!curl_multi){
+        if(!curl_multi){
             /* Clean all */
-            if (update_window) {
+            if(update_window){
                 gtk_widget_destroy(update_window);
                 update_window = NULL;
             }
@@ -523,16 +526,17 @@ gboolean download_html(gpointer data) {
     return FALSE;
 }
 /*******************************************************************************/
-void clean_download(void) {
+void
+clean_download(void){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    if (curl_multi)
+    if(curl_multi)
         curl_multi_cleanup(curl_multi);
     curl_multi = NULL;
     curl_handle = NULL;
     curl_handle_hour = NULL;
-    if (update_window) {
+    if (update_window){
         gtk_widget_destroy(update_window);
         update_window = NULL;
     }
@@ -545,12 +549,11 @@ gboolean
 get_station_url(gchar ** url, struct HtmlFile *html_file,
                 gchar ** hour_url, struct HtmlFile *html_file_hour,
                 gboolean first) {
-    gboolean valid = FALSE;
-    static GtkTreeIter iter;
-    gchar	*station_code = NULL,
-		*station_source = NULL;
-    gint	source = 0;
-    gchar buffer[512];
+    gboolean            valid = FALSE;
+    static GtkTreeIter  iter;
+    gchar               *station_code = NULL,
+                        *station_source = NULL;
+    gchar                buffer[512];
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -569,28 +572,24 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
                            ID0_COLUMN, &station_code,
                            3, &station_source,
                            -1);
-/* !!! TODO: recode this */
-        /* Default weather.com */
-        if (station_source){
-            if(!strcmp(station_source, "weather.com"))
-                source = 0;
-            if(!strcmp(station_source, "rp5.ru"))
-                source = 1;
-        }else
-                source = 0;
-        /* prepare url */
-        if(weather_sources[source].url){
-	    *buffer = 0;
-	    snprintf(buffer, sizeof(buffer) - 1,
-			weather_sources[source].url, station_code);
-	    *url = g_strdup(buffer);
-	}
-        if(weather_sources[source].hour_url){
-	    *buffer = 0;
-	    snprintf(buffer, sizeof(buffer) - 1,
-			weather_sources[source].hour_url, station_code);
-	    *hour_url = g_strdup(buffer);
-	}
+    if(station_source){
+        /* prepare forecast url */
+        if(get_source_forecast_url(app->sources_list, station_source)){
+            *buffer = 0;
+            snprintf(buffer, sizeof(buffer) - 1,
+                        get_source_forecast_url(app->sources_list, station_source),
+                        station_code);
+            *url = g_strdup(buffer);
+        }
+        /* prepare detail url */
+        if(get_source_detail_url(app->sources_list, station_source)){
+            *buffer = 0;
+            snprintf(buffer, sizeof(buffer) - 1,
+                        get_source_detail_url(app->sources_list, station_source),
+                        station_code);
+            *hour_url = g_strdup(buffer);
+        }
+    }
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>>>>>>URL %s\n", *url);
 #endif
@@ -619,3 +618,12 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
 #endif
     return valid;
 }
+/*******************************************************************************/
+gboolean
+get_file(const gchar *full_url, const gchar *full_storing_name){
+    if(!full_url || !full_storing_name)
+        return FALSE;
+
+    return TRUE;
+}
+/*******************************************************************************/
