@@ -32,7 +32,7 @@
 #include "weather-common.h"
 #include <curl/multi.h>
 
-#if !defined OS2008 && !defined OS2009
+#if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
 #include <osso-ic.h>
 #include <osso-ic-dbus.h>
 #endif
@@ -58,15 +58,7 @@ GtkWidget* create_window_update(void);
 #ifdef USE_CONIC
     void connection_cb(ConIcConnection * connection,ConIcConnectionEvent * event, gpointer user_data);
 #endif
-
-/*******************************************************************************/
-extern WeatherSource	weather_sources[];
-/*******************************************************************************/
-extern void config_update_proxy(void);
-extern void add_current_time_event(void);
-extern void popup_window_destroy(void);
-extern void update_weather(gboolean show_update_window);
-extern void redraw_home_window(gboolean first_start);
-extern void destroy_popup_window(void);
+gboolean get_file(const gchar *full_url, const gchar *full_storing_name);
+void free_curl(void);
 /*******************************************************************************/
 #endif
