@@ -28,23 +28,29 @@
 */
 /*******************************************************************************/
 #include "weather-event.h"
+#include "weather-home.h"
 #ifdef RELEASE
 #undef DEBUGFUNCTIONCALL
 #endif
+
+
 /*******************************************************************************/
 gboolean not_event = FALSE;
 /*******************************************************************************/
 static GSList *event_time_list = NULL;
 /*******************************************************************************/
 gboolean 
-timer_handler(gpointer data) {
-    static GSList *list_time_event_temp = NULL;
-    struct event_time *evt;
-    time_t current_time;
-    int check;
-    gchar buffer[2048];
+timer_handler(gpointer data){
+    static GSList       *list_time_event_temp = NULL;
+    struct event_time   *evt;
+    time_t              current_time;
+    int                 check;
+#ifdef ENABLE_GPS
+    gchar               buffer[2048];
+#endif
+    double distance;
 #ifdef DEBUGEVENTS
-    char *temp_string;
+    char                *temp_string;
 #endif
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -120,18 +126,17 @@ timer_handler(gpointer data) {
                                                     app->temporary_station_latitude,app->temporary_station_longtitude));
 
 */
+                distance = calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
+                                                    app->temporary_station_latitude,app->temporary_station_longtitude);
+/*
                 sprintf(buffer,"Event:  Calculate CHECK_GPS_POSITION %f %f %f %f %f\n",
                                     app->gps_station.latitude,app->gps_station.longtitude,
                                     app->temporary_station_latitude,app->temporary_station_longtitude,
-                                    calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
-                                                    app->temporary_station_latitude,app->temporary_station_longtitude));
+                                    distance);
                 write_log(buffer);
-                write_log(app->gps_station.name);
-                if (calculate_distance
-                    (app->gps_station.latitude,
-                     app->gps_station.longtitude,
-                     app->temporary_station_latitude,
-                     app->temporary_station_longtitude) > 10) {
+*/
+
+                if (distance > 10 || distance < 0) {
 
                     get_nearest_station
                         (app->temporary_station_latitude,
@@ -149,19 +154,22 @@ timer_handler(gpointer data) {
                                 g_free(app->config->current_source);
                             app->config->current_source =
                                 g_strdup("weather.com");
+
                         add_station_to_user_list(app->gps_station.name,
                                                  app->gps_station.id0,
-                                                 TRUE, app->config->current_source);
+                                                 TRUE, app->config->current_source, -1);
                         if (!app->config->current_station_name
                             && !app->config->current_station_id) {
                             /* Fix me if source are not weather.com */
                             if (app->config->current_station_name)
                                 g_free(app->config->current_station_name);
-                            app->config->current_station_name = g_strdup(app->gps_station.name);
+                            app->config->current_station_name =
+                                g_strdup(app->gps_station.name);
 
                             if (app->config->current_station_id)
                                 g_free(app->config->current_station_id);
-                            app->config->current_station_id = g_strdup(app->gps_station.id0);
+                            app->config->current_station_id =
+                                g_strdup(app->gps_station.id0);
                         }
                         config_save(app->config);
                         update_weather(FALSE);
@@ -328,9 +336,9 @@ void event_add(time_t time_value, short type_event) {
 /*  Addition the periodic time in the list of events  for weather forecast updating.  
     Interval is a count of minutes for the next interval */
 void add_gps_event(guint interval) {
-//#ifdef DEBUGFUNCTIONCALL
+#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-//#endif
+#endif
 #ifdef DEBUGEVENTS
     fprintf(stderr, "Add in list\n");
     print_list(NULL, 0);
