@@ -28,6 +28,8 @@
 /*******************************************************************************/
 #include "weather-sensor.h"
 #include "weather-utils.h"
+#include "weather-settings.h"
+#include "weather-home.h"
 #include <string.h>
 #include <stdlib.h>
 #ifdef RELEASE
@@ -223,10 +225,33 @@ gboolean read_sensor(gboolean need_redraw) {
 }
 
 /*******************************************************************************/
-WDB *create_sensor_icon_widget(const int icon_size, gboolean transparency,
-                               gboolean draw_day_label, GdkColor * color) {
+WDB *create_sensor_icon_widget(gboolean transparency, gboolean draw_day_label,
+                                GdkColor * color) {
     gchar buffer[256], buffer_icon[256];
+    gint icon_size;
 
+/* select image size */
+    switch(app->config->icons_size){
+        case GIANT:
+            icon_size = GIANT_ICON_SIZE;
+            break;
+        default:
+        case LARGE:
+            icon_size = LARGE_ICON_SIZE;
+            break;
+        case MEDIUM:
+            icon_size = MEDIUM_ICON_SIZE;
+            break;
+        case SMALL:
+            icon_size = SMALL_ICON_SIZE;
+            break;
+        case TINY:
+            icon_size = TINY_ICON_SIZE;
+            break;
+    }
+#if defined(NONMAEMO) || defined (APPLICATION)
+    icon_size = MEDIUM_ICON_SIZE;
+#endif
     /* prepare temperature data */
     buffer[0] = 0;
     snprintf(buffer, sizeof(buffer) - 1,
@@ -240,8 +265,9 @@ WDB *create_sensor_icon_widget(const int icon_size, gboolean transparency,
     buffer_icon[0] = 0;
     snprintf(buffer_icon, sizeof(buffer_icon) - 1, "%ssensor.png",
              BUTTON_ICONS);
-    return create_weather_day_button(buffer, buffer_icon, icon_size,
-                                     transparency, draw_day_label, color);
+    return create_weather_day_button(buffer, buffer_icon, OTHER_BUTTON,
+                                     transparency, draw_day_label, color,
+                                     UNKNOWN_DIRECTION, -1);
 }
 
 /*******************************************************************************/
