@@ -389,10 +389,16 @@ GtkWidget *create_tree_view(GtkListStore * list) {
     START_FUNCTION;
 #endif
 /* create the tree view model LIST */
+#if defined OS2009
+    tree_view = hildon_gtk_tree_view_new_with_model(HILDON_UI_MODE_NORMAL, GTK_TREE_MODEL(list));
+#else
     tree_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list));
+#endif
 /* make the list component single selectable */
+#if !defined OS2009 
     list_selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_view));
     gtk_tree_selection_set_mode(list_selection, GTK_SELECTION_SINGLE);
+#endif
 /* add name column to the view */
     renderer = gtk_cell_renderer_text_new();
     column = gtk_tree_view_column_new();
@@ -526,11 +532,92 @@ change_state_window(GtkWidget *window){
     END_FUNCTION;
 #endif
 }
+/*******************************************************************************/
+gint
+choose_wind_direction(gchar *buffer)
+{
+    /* if buffer is null or CALM */
+    if (!buffer || 
+        (buffer[0] == 'C' && buffer[1] == 'A'))
+        return UNKNOWN_DIRECTION;
+    if (buffer[0] == 'N'){
+        if (strlen(buffer) > 1){
+            if (buffer[1] == 'W')
+                return TO_SOUTH_EAST;
+            else{
+               if (buffer[1] == 'E')
+                    return TO_SOUTH_WEST;
+               else
+                    return TO_SOUTH;
+            }
+        }else   
+            return TO_SOUTH;
+    }else{
+        if (buffer[0] == 'S'){
+            if (strlen(buffer) > 1){
+                if (buffer[1] == 'W')
+                    return TO_NORTH_EAST;
+                else{
+                    if (buffer[1] == 'E')
+                        return TO_NORTH_WEST;
+                    else
+                        return TO_NORTH;
+                }
+            }else
+                    return TO_NORTH;
+        }else
+        if (buffer[0] == 'W')
+            return TO_EAST;
+        if (buffer[0] == 'E')
+            return TO_WEST;
+    }
+}
 
+/*******************************************************************************/
+GtkWidget*
+create_button_with_2_line_text(const gchar *first_line_text, const gchar *second_line_text,
+                                const gint first_line_text_size, const gint second_line_text_size){
+    GtkWidget *first_line = NULL,
+              *second_line  = NULL,
+              *vertical_box  = NULL,
+              *button = NULL;
+#if defined OS2009
+  button = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
+                    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+                     first_line_text,
+                     second_line_text);
+#else
+    button = gtk_button_new();
+
+    first_line = gtk_label_new(first_line_text);
+    set_font(first_line, NULL, first_line_text_size);
+    gtk_widget_show(first_line);
+
+    second_line = gtk_label_new(second_line_text);
+    set_font(second_line, NULL, second_line_text_size);
+    gtk_widget_show(second_line);
+
+    vertical_box = gtk_vbox_new(FALSE, 2);
+    gtk_widget_show(vertical_box);
+
+    g_object_set_data(G_OBJECT(button), "vbox", (gpointer)vertical_box);
+    g_object_set_data(G_OBJECT(button), "label", (gpointer)second_line);
+
+    gtk_box_pack_start(GTK_BOX(vertical_box), first_line, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(vertical_box), second_line, TRUE, TRUE, 0);
+    gtk_container_add(GTK_CONTAINER(button), vertical_box);
+
+
+#endif
+    gtk_widget_show(button);
+    return button;
+}
+/*******************************************************************************/
 /* For debugging   */
+/*
 void write_log(char *string)
 {
 FILE *filelog; filelog=fopen("/tmp/omw.log","a+"); fprintf(filelog,"\n%s\n", string);fflush(filelog);fclose(filelog);
 }
 
-
+*/
\ No newline at end of file
